rename generic_setattr
authorChristoph Hellwig <hch@lst.de>
Fri, 4 Jun 2010 09:30:00 +0000 (11:30 +0200)
committerAl Viro <viro@zeniv.linux.org.uk>
Mon, 9 Aug 2010 20:47:35 +0000 (16:47 -0400)
Despite its name it's now a generic implementation of ->setattr, but
rather a helper to copy attributes from a struct iattr to the inode.
Rename it to setattr_copy to reflect this fact.

Signed-off-by: Christoph Hellwig <hch@lst.de>
Signed-off-by: Al Viro <viro@zeniv.linux.org.uk>
fs/attr.c
fs/ext2/inode.c
fs/fat/file.c
fs/libfs.c
fs/ramfs/file-nommu.c
fs/sysfs/inode.c
include/linux/fs.h
mm/shmem.c

index b4fa3b0..1f6a895 100644 (file)
--- a/fs/attr.c
+++ b/fs/attr.c
@@ -105,13 +105,13 @@ out_big:
 EXPORT_SYMBOL(inode_newsize_ok);
 
 /**
* generic_setattr - copy simple metadata updates into the generic inode
  * @inode:     the inode to be updated
  * @attr:      the new attributes
  *
* generic_setattr must be called with i_mutex held.
  *
* generic_setattr updates the inode's metadata with that specified
  * in attr. Noticably missing is inode size update, which is more complex
  * as it requires pagecache updates. See simple_setsize.
  *
@@ -119,7 +119,7 @@ EXPORT_SYMBOL(inode_newsize_ok);
  * that for "simple" filesystems, the struct inode is the inode storage.
  * The caller is free to mark the inode dirty afterwards if needed.
  */
-void generic_setattr(struct inode *inode, const struct iattr *attr)
+void setattr_copy(struct inode *inode, const struct iattr *attr)
 {
        unsigned int ia_valid = attr->ia_valid;
 
@@ -144,11 +144,11 @@ void generic_setattr(struct inode *inode, const struct iattr *attr)
                inode->i_mode = mode;
        }
 }
-EXPORT_SYMBOL(generic_setattr);
+EXPORT_SYMBOL(setattr_copy);
 
 /*
  * note this function is deprecated, the new truncate sequence should be
* used instead -- see eg. simple_setsize, generic_setattr.
  */
 int inode_setattr(struct inode *inode, const struct iattr *attr)
 {
@@ -163,7 +163,7 @@ int inode_setattr(struct inode *inode, const struct iattr *attr)
                        return error;
        }
 
-       generic_setattr(inode, attr);
+       setattr_copy(inode, attr);
 
        mark_inode_dirty(inode);
 
index 74dfe5f..7dee7b3 100644 (file)
@@ -1544,7 +1544,7 @@ int ext2_setattr(struct dentry *dentry, struct iattr *iattr)
                if (error)
                        return error;
        }
-       generic_setattr(inode, iattr);
+       setattr_copy(inode, iattr);
        if (iattr->ia_valid & ATTR_MODE)
                error = ext2_acl_chmod(inode);
        mark_inode_dirty(inode);
index 990dfae..20813d2 100644 (file)
@@ -446,7 +446,7 @@ int fat_setattr(struct dentry *dentry, struct iattr *attr)
                        goto out;
        }
 
-       generic_setattr(inode, attr);
+       setattr_copy(inode, attr);
        mark_inode_dirty(inode);
 out:
        return error;
index dcaf972..861a887 100644 (file)
@@ -395,8 +395,7 @@ int simple_setattr(struct dentry *dentry, struct iattr *iattr)
                        return error;
        }
 
-       generic_setattr(inode, iattr);
-
+       setattr_copy(inode, iattr);
        return error;
 }
 EXPORT_SYMBOL(simple_setattr);
index d532c20..8d44f03 100644 (file)
@@ -183,7 +183,7 @@ static int ramfs_nommu_setattr(struct dentry *dentry, struct iattr *ia)
                }
        }
 
-       generic_setattr(inode, ia);
+       setattr_copy(inode, ia);
  out:
        ia->ia_valid = old_ia_valid;
        return ret;
index 0835a3b..7e187fb 100644 (file)
@@ -122,7 +122,7 @@ int sysfs_setattr(struct dentry *dentry, struct iattr *iattr)
                goto out;
 
        /* this ignores size changes */
-       generic_setattr(inode, iattr);
+       setattr_copy(inode, iattr);
 
 out:
        mutex_unlock(&sysfs_mutex);
index b347b2d..8ebb5f0 100644 (file)
@@ -2393,7 +2393,7 @@ extern int buffer_migrate_page(struct address_space *,
 extern int inode_change_ok(const struct inode *, struct iattr *);
 extern int inode_newsize_ok(const struct inode *, loff_t offset);
 extern int __must_check inode_setattr(struct inode *, const struct iattr *);
-extern void generic_setattr(struct inode *inode, const struct iattr *attr);
+extern void setattr_copy(struct inode *inode, const struct iattr *attr);
 
 extern void file_update_time(struct file *file);
 
index f65f840..3b58ad6 100644 (file)
@@ -811,7 +811,7 @@ static int shmem_notify_change(struct dentry *dentry, struct iattr *attr)
 
        error = inode_change_ok(inode, attr);
        if (!error)
-               generic_setattr(inode, attr);
+               setattr_copy(inode, attr);
 #ifdef CONFIG_TMPFS_POSIX_ACL
        if (!error && (attr->ia_valid & ATTR_MODE))
                error = generic_acl_chmod(inode);
@@ -105,13 +105,13 @@ out_big:
 
 /**
- * generic_setattr - copy simple metadata updates into the generic inode
+ * setattr_copy - copy simple metadata updates into the generic inode
  * @inode:     the inode to be updated
  * @attr:      the new attributes
@@ -105,13 +105,13 @@ out_big:
  * @attr:      the new attributes
  *
- * generic_setattr must be called with i_mutex held.
+ * setattr_copy must be called with i_mutex held.
  *
@@ -105,13 +105,13 @@ out_big:
  *
- * generic_setattr updates the inode's metadata with that specified
+ * setattr_copy updates the inode's metadata with that specified
  * in attr. Noticably missing is inode size update, which is more complex
  * as it requires pagecache updates. See simple_setsize.
@@ -144,11 +144,11 @@ void generic_setattr(struct inode *inode, const struct iattr *attr)
 /*
  * note this function is deprecated, the new truncate sequence should be
- * used instead -- see eg. simple_setsize, generic_setattr.
+ * used instead -- see eg. simple_setsize, setattr_copy.
  */
 int inode_setattr(struct inode *inode, const struct iattr *attr)